@@ -1,4 +1,4 @@
-# Copyright (c) 2020, 2021, Oracle and/or its affiliates.
+# Copyright (c) 2020, 2022, Oracle and/or its affiliates.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2.0, as
@@ -92,7 +92,9 @@ CEXT_OPTIONS = [
     ("extra-compile-args=", None,
      "extra compile args"),
     ("extra-link-args=", None,
-     "extra link args")
+     "extra link args"),
+    ("skip-vendor", None,
+     "Skip bundling vendor libraries"),
 ]
 
 LOGGER = logging.getLogger(__name__)
@@ -108,7 +110,7 @@ class BaseCommand(Command):
     """Base command class for Connector/Python."""
 
     user_options = COMMON_USER_OPTIONS + CEXT_OPTIONS
-    boolean_options = ["debug", "byte_code_only", "keep-temp"]
+    boolean_options = ["debug", "byte_code_only", "keep_temp", "skip_vendor"]
 
     with_mysql_capi = None
     with_mysqlxpb_cext = False
@@ -128,6 +130,7 @@ class BaseCommand(Command):
     label = None
     debug = False
     keep_temp = False
+    skip_vendor = False
     build_base = None
     log = LOGGER
     vendor_folder = os.path.join("lib", "mysql", "vendor")
@@ -152,6 +155,7 @@ class BaseCommand(Command):
         self.label = None
         self.debug = False
         self.keep_temp = False
+        self.skip_vendor = False
 
     def finalize_options(self):
         """Finalize the options."""
@@ -192,7 +196,12 @@ class BaseCommand(Command):
             self.extra_link_args or
             os.environ.get("EXTRA_LINK_ARGS")
         )
-        self._copy_vendor_libraries()
+        cmd_build_ext.skip_vendor = (
+            self.skip_vendor or
+            os.environ.get("SKIP_VENDOR")
+        )
+        if not cmd_build_ext.skip_vendor:
+            self._copy_vendor_libraries()
 
     def remove_temp(self):
         """Remove temporary build files."""
@@ -240,42 +249,34 @@ class BaseCommand(Command):
         if self.with_mysql_capi:
             plugin_ext = "dll" if os.name == "nt" else "so"
             plugin_path = os.path.join(self.with_mysql_capi, "lib", "plugin")
-
-            # authentication_ldap_sasl_client
-            plugin_name = (
-                "authentication_ldap_sasl_client.{}".format(plugin_ext)
-            )
-            plugin_full_path = os.path.join(plugin_path, plugin_name)
-            self.log.debug("ldap plugin_path: '%s'", plugin_full_path)
-            if os.path.exists(plugin_full_path):
-                bundle_plugin_libs = True
-                vendor_libs.append(
-                    (plugin_path, [os.path.join("plugin", plugin_name)])
-                )
-
-            # authentication_kerberos_client
-            plugin_name = (
-                "authentication_kerberos_client.{}".format(plugin_ext)
-            )
-            plugin_full_path = os.path.join(plugin_path, plugin_name)
-            self.log.debug("kerberos plugin_path: '%s'", plugin_full_path)
-            if os.path.exists(plugin_full_path):
-                bundle_plugin_libs = True
-                vendor_libs.append(
-                    (plugin_path, [os.path.join("plugin", plugin_name)])
-                )
-
-            # authentication_oci_client
-            plugin_name = (
-                "authentication_oci_client.{}".format(plugin_ext)
-            )
-            plugin_full_path = os.path.join(plugin_path, plugin_name)
-            self.log.debug("OCI IAM plugin_path: '%s'", plugin_full_path)
-            if os.path.exists(plugin_full_path):
-                bundle_plugin_libs = True
-                vendor_libs.append(
-                    (plugin_path, [os.path.join("plugin", plugin_name)])
+            plugin_list = [
+                (
+                    "LDAP",
+                    "authentication_ldap_sasl_client.{}".format(plugin_ext),
+                ),
+                (
+                    "Kerberos",
+                    "authentication_kerberos_client.{}".format(plugin_ext),
+                ),
+                (
+                    "OCI IAM",
+                    "authentication_oci_client.{}".format(plugin_ext),
+                ),
+                (
+                    "FIDO",
+                    "authentication_fido_client.{}".format(plugin_ext),
+                ),
+            ]
+            for plugin_name, plugin_file in plugin_list:
+                plugin_full_path = os.path.join(plugin_path, plugin_file)
+                self.log.debug(
+                    "%s plugin_path: '%s'", plugin_name, plugin_full_path,
                 )
+                if os.path.exists(plugin_full_path):
+                    bundle_plugin_libs = True
+                    vendor_libs.append(
+                        (plugin_path, [os.path.join("plugin", plugin_file)])
+                    )
 
             # vendor libraries
             if bundle_plugin_libs and os.name == "nt":
@@ -352,13 +353,13 @@ class BaseCommand(Command):
             if not os.path.exists(sasl_libs_path):
                 self.log.info("sasl2 llibraries not found at %s",
                               sasl_libs_path)
-                self.distribution.package_data = {
-                    "mysql": ["vendor/*"]}
             sasl_libs = []
             sasl_plugin_libs_w = [
                 "libsasl2.*.*", "libgssapi_krb5.*.*", "libgssapi_krb5.*.*",
                 "libkrb5.*.*", "libk5crypto.*.*", "libkrb5support.*.*",
-                "libcrypto.*.*.*", "libssl.*.*.*", "libcom_err.*.*"]
+                "libcrypto.*.*.*", "libssl.*.*.*", "libcom_err.*.*",
+                "libfido2.*.*",
+            ]
             sasl_plugin_libs = []
             for sasl_lib in sasl_plugin_libs_w:
                 lib_path_entries = glob(os.path.join(
@@ -391,8 +392,6 @@ class BaseCommand(Command):
             if not os.path.exists(sasl2_libs_path):
                 self.log.info("sasl2 llibraries not found at %s",
                               sasl2_libs_path)
-                self.distribution.package_data = {"mysql": ["vendor/*"]}
-                return
             sasl2_libs_w = [
                 "libanonymous.*", "libcrammd5.*.*", "libdigestmd5.*.*.*.*",
                 "libgssapiv2.*", "libplain.*.*", "libscram.*.*.*.*",
@@ -633,7 +632,7 @@ class BuildExt(build_ext, BaseCommand):
                 if self.extra_link_args:
                     ext.extra_link_args.extend(self.extra_link_args.split())
                 # Add -rpath if the platform is Linux
-                if platform.system() == "Linux":
+                if platform.system() == "Linux" and not self.skip_vendor:
                     ext.extra_link_args.extend([
                         "-Wl,-rpath,$ORIGIN/mysql/vendor"])
                 # Add include dirs
