@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014, 2021, Oracle and/or its affiliates.
+ * Copyright (c) 2014, 2022, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0, as
@@ -739,6 +739,11 @@ mytopy_string(const char *data,
         return PyByteArray_FromStringAndSize(data, field_length);
     }
 
+    if (data[0] == '\0')
+    {
+        return PyUnicode_FromString("");
+    }
+
     /* 'binary' charset = 63 */
     if (use_unicode && (field_type == MYSQL_TYPE_JSON || field_charsetnr != 63))
     {
